<?php

namespace Controller;

use Exception\CustomException;
use Zeedhi\Framework\Controller\Simple;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Util\Messages;
use Zeedhi\DevOps\Util\Utilities;


class Attachment extends Simple
{
    /** @var \Service\Attachment $attachmentService */
    protected $attachmentService;

    public function __construct(\Service\Attachment $attachmentService) {
        $this->attachmentService = $attachmentService;
    }
    
    public function newCallAttachment(Request\DataSet $request, Response $response) {
        try {
            $row                = $request->getDataSet()->getRows();
            $row                = $row[0];
            $subject            = isset($row["SUBJECT"]) ? $row["SUBJECT"] : '';
            $description        = empty($row['DESCRIPTION']) ? null : $row['DESCRIPTION'];
            $supportCallId      = empty($row['CALL_ID']) ? null : $row['CALL_ID'];
            $createdBy          = empty($row['CREATED_BY']) ? null : $row['CREATED_BY'];
            $document           = empty($row['DOCUMENT']) ? null : $row['DOCUMENT'];
            $callRelationship   = empty($row['CALL_RELATIONSHIP']) ? null : $row['CALL_RELATIONSHIP'];
            $mainTypeCall       = empty($row['MAIN_TYPE_CALL']) ? null : $row['MAIN_TYPE_CALL'];
            $callType           = isset($row["CALL_TYPE"]) ? $row["CALL_TYPE"] : null;
            
            $this->attachmentService->newCallAttachment($supportCallId, $description, $document, $createdBy, $callRelationship, $mainTypeCall, $subject, $callType);
        } catch (CustomException $e) {
            $response->setError(\Util\Utilities::getErrorObjectFromException($e));
        }
    }


    public function saveRichClientAttachments(Request\DataSet $request, Response $response) {
        try {
            $row                = $request->getDataSet()->getRows()[0];
            $description        = empty($row['DESCRIPTION']) ? null : $row['DESCRIPTION'];
            $supportCallId      = empty($row['CALL_ID']) ? null : $row['CALL_ID'];
            $createdBy          = empty($row['CREATED_BY']) ? null : $row['CREATED_BY'];
            $document           = empty($row['DOCUMENT']) ? null : $row['DOCUMENT'];
            $callRelationship   = empty($row['CALL_RELATIONSHIP']) ? null : $row['CALL_RELATIONSHIP'];
            $this->attachmentService->addAttachmentsRichClient($supportCallId, $description, $document, $createdBy, $callRelationship);
        } catch (CustomException $e) {
            $response->setError(\Util\Utilities::getErrorObjectFromException($e));
        }
    }


    public function downLoadAttachment(Request $request, Response $response)
    {
        try {
            $row = $request->getDataSet()->getRows();
            $row = $row[0];
            $attachmentId = isset($row['ID']) ? $row['ID'] : null;
            $callAttachmentId = isset($row['NRCALLATTACHMENT']) ? $row['NRCALLATTACHMENT'] : null;
            $this->attachmentService->downLoadAttachment($attachmentId, $callAttachmentId);
        } catch(CustomException $e) {
            $response->setError(\Util\Utilities::getErrorObjectFromException($e));
        }
    }

    public function downLoadAttachmentTicket(Request $request, Response $response)
    {
        try {
            $row = $request->getDataSet()->getRows();
            $row = $row[0];
            $attachmentId = isset($row['ID']) ? $row['ID'] : null;
            $this->attachmentService->downLoadAttachmentTicket($attachmentId);
        } catch(CustomException $e) {
            $response->setError(\Util\Utilities::getErrorObjectFromException($e));
        }
    }

    public function downLoadSpecification(Request $request, Response $response)
    {
        try {
            $row = $request->getDataSet()->getRows();
            $row = $row[0];
            $issueId = isset($row['ISSUE_ID']) ? $row['ISSUE_ID'] : null;
            $this->attachmentService->downLoadSpecification($issueId);
        } catch(CustomException $e) {
            $response->setError(\Util\Utilities::getErrorObjectFromException($e));
        }
    }

    public function downLoadAttachmentGEP(Request $request, Response $response)
    {
        try {
            $row = $request->getDataSet()->getRows();
            $row = $row[0];
            $fileName = isset($row['FILENAME']) ? $row['FILENAME'] : null;
            $this->attachmentService->downLoadAttachmentGEP($fileName);
        } catch(CustomException $e) {
            throw $e;
        }
    }

    public function getSupportCallAttachmentsDataSet(Request\Filter $request, Response $response) {
        $params = $request->getFilterCriteria()->getConditions();
        if(!empty($params) && !empty($params[0]['value'])) {
            $callId             = Utilities::getValueInFilterDataSourceByName($params,'CALL_ID');
            $callRelationship   = Utilities::getValueInFilterDataSourceByName($params,'CALL_RELATIONSHIP');
            $attachments = $this->attachmentService->getSupportCallAttachmentsDataSet($callRelationship);
            $response->addDataSet(new DataSet('supportCallAttachments', $attachments));
        } else {
            $response->addDataSet(new DataSet('supportCallAttachments', array()));
        }
    }

    public function deleteSupportCallAttachments(Request\DataSet $request, Response $response) {
        try {
            $rows = $request->getDataSet()->getRows();
            $this->attachmentService->deleteSupportCallAttachments($rows);
        } catch (\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_WARNING));
        }
    }

    public function newProductCallAttachment(Request\DataSet $request, Response $response) {
        try {
            $row = $request->getDataSet()->getRows()[0];
            $productCallId    = empty($row['CALL_ID']) ? null : $row['CALL_ID'];
            $callRelationship = empty($row['CALL_RELATIONSHIP']) ? null : $row['CALL_RELATIONSHIP'];
            $createdBy        = empty($row['CREATED_BY']) ? null : $row['CREATED_BY'];
            $document         = empty($row['DOCUMENT']) ? null : $row['DOCUMENT'];
            $this->attachmentService->addAttachmentsProductCall($productCallId, $document, $createdBy, $callRelationship);
        } catch (CustomException $e) {
            $response->setError(\Util\Utilities::getErrorObjectFromException($e));
        }
    }
    
    public function getCallAttachmentsDataSet(Request\Filter $request, Response $response)
    {
        
        $params = $request->getFilterCriteria()->getConditions();
        if(!empty($params) && !empty($params[0]["value"])) {
            $callRelationship   = Utilities::getValueInFilterDataSourceByName($params,'CALL_RELATIONSHIP');
            $callType           = Utilities::getValueInFilterDataSourceByName($params,'CALL_TYPE');
            $callId             = Utilities::getValueInFilterDataSourceByName($params,'CALL_ID');
            $mainTypeCall       = Utilities::getValueInFilterDataSourceByName($params,'MAIN_TYPE_CALL');
            $commentId          = Utilities::getValueInFilterDataSourceByName($params,'COMMENT_ID');
            $filename           = Utilities::getValueInFilterDataSourceByName($params,'FILENAME');
            $attachments = $this->attachmentService->getCallAttachmentsDataSet($callId, $callRelationship,
                $callType, $mainTypeCall,$commentId,$filename);
            
            $response->addDataSet(new DataSet('callAttachments', $attachments));
        } else {
            $response->addDataSet(new DataSet('callAttachments', array()));
        }
    }

    public function getProductCallAttachmentsDataSet(Request\Filter $request, Response $response)
    {
        $params = $request->getFilterCriteria()->getConditions();
        if(!empty($params) && !empty($params[0]["value"])) {
            $callRelationship = Utilities::getValueInFilterDataSourceByName($params,'CALL_RELATIONSHIP');
            $callType         = Utilities::getValueInFilterDataSourceByName($params,'CALL_TYPE');
            $attachments = $this->attachmentService->getProductCallAttachmentsDataSet($callRelationship, $callType);
            $response->addDataSet(new DataSet('productCallAttachments', $attachments));
        } else {
            $response->addDataSet(new DataSet('productCallAttachments', array()));
        }
    }

    public function deleteProductCallAttachments(Request\DataSet $request, Response $response) {
        try {
            $rows = $request->getDataSet()->getRows();
            foreach ($rows as $row) {
                $id = $row['ID'];
                $isIssue = isset($row['__fromIssue'])?$row['__fromIssue']:null;
                $dir = isset($row['FILENAME'])?$row['FILENAME']:null;
                $this->attachmentService->deleteProductCallAttachments($id,$isIssue,$dir);
            }

        } catch (\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_WARNING));
        }

    }

    
} 